@@ -6,7 +6,7 @@ import pycodestyle
 class Flake8Pep3101(object):
 
     name = 'flake8_pep3101'
-    version = '1.0'
+    version = '1.1'
     message = 'S001 found module formatter'
 
     def __init__(self, tree, filename):
@@ -15,7 +15,7 @@ class Flake8Pep3101(object):
 
     def run(self):
         if self.filename is 'stdin':
-            lines = pycodestyle.stdin_get_value().splitlines()
+            lines = pycodestyle.stdin_get_value()
             tree = ast.parse(lines)
         elif self.tree:
             tree = self.tree
@@ -26,5 +26,5 @@ class Flake8Pep3101(object):
         for stmt in ast.walk(tree):
             if isinstance(stmt, ast.BinOp) and \
                     isinstance(stmt.op, ast.Mod) and \
-                    isinstance(stmt.left, ast.Str):
+                    isinstance(stmt.left, (ast.Str, ast.Name)):
                 yield stmt.lineno, stmt.col_offset, self.message, type(self)
